@@ -3,9 +3,9 @@ package jdk.internal.jshell.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "25.0.2+10" },
-            { "jdk", "25.0.2" },
-            { "release", "25.0.2" },
+            { "full", "25+36" },
+            { "jdk", "25" },
+            { "release", "25" },
         };
     }
 }
